<?php

/*  Alternate WebshopEngine
(C) 2009-2014 by Alternate Tools
-----------------------------------------------------

File:         shop_article_basket.php
Description:  Shop overview of all active articles

*/
    include "../modules/mod_config.php";
    include "../modules/mod_shop.php";

    // Check for maintenance mode...
    if ($SHOP_MAINTENANCE_MODE == true)
    {
        include $ADMIN_MAINTENANCE_SITE;
        return;
    }

    // Check for login...
    if (check_login() == false && $FORCE_CUSTOMER_LOGIN == true)
    {
        header ("location: " . $SHOP_LOGIN_SITE);
        return;
    }

    include "../modules/class_article.php";
    include "../modules/class_basket.php";
    include "../modules/class_translation.php";
    include "../modules/class_textfile.php";

    // Session starts first :-)
    $basket = new cBasket;
    $basket->SetCustFieldCount($ARTICLE_CUSTOM_FIELD_COUNT);
    $basket->InitSession();
    $basket->LoadFromSession();
    $basketCount = 0;
    $basketValue = 0;

    $cFile = new cTextFile;
    $errorMessage = "";

    $art = new cArticle;
    $art->SetFolder($ARTICLE_FOLDER);
    $art->SetCustFieldCount($ARTICLE_CUSTOM_FIELD_COUNT);

    // Cancel the basket
    if (isset($_POST['bsk_Cancel']) == true)
    {
        header("location: " . $SHOP_MAIN_SITE);
        return;
    }

    // Clear the basket
    if (isset($_POST['bsk_Clear']) == true)
    {
        $basket->ClearBasket();
        $basket->SaveToSession();
    }

    // Go to cash desk
    if (isset($_POST['bsk_CashDesk']) == true)
    {
        header("location: " . $SHOP_ORDER_SITE);
        return;
    }

    // Remove article from basket
    if (isset($_POST['bsk_Remove']) == true)
    {
        if (isset($_POST['art_index']) == true)
        {
            if($basket->RemoveArticle($_POST['art_index']) == true)
               $basket->SaveToSession();
        }
    }

    // Save article to basket
    if (isset($_POST['bsk_Save']) == true)
    {
        if (isset($_POST['art_cnt']) == true && isset($_POST['art_index']) == true && isset($_POST['art_id']) == true)
        {
            $artCount = 1;
            if (is_numeric($_POST['art_cnt']) == true && $_POST['art_cnt'] > 0)
            {
                // Check maximum amount
                if ($_POST['art_cnt'] <= $SHOP_MAX_ARTICLE_COUNT)
                    $artCount = $_POST['art_cnt'];
                else
                {
                    $artCount = $SHOP_MAX_ARTICLE_COUNT;
                    $errorMessage = $cTrans->GetTranslation('shop_basket_errormaxcount');
                }
                // Check available article amount
                $art->LoadArticleFromId($_POST['art_id']);
                if ($USE_ARTICLE_AMOUNTS == true && ($art->IsArticleAmountUnlimited() == false && $artCount > $art->GetArticleAmount()))
                {
                    $artCount = $art->GetArticleAmount();
                    $errorMessage = $cTrans->GetTranslation('shop_basket_errormaxamount');
                }
            }
            if ($basket->SetArticleCount($_POST['art_index'], $artCount) == true)
                $basket->SaveToSession();
        }
    }

    // Display baskets content
    $contPage = build_page($SHOP_THEME, false, true, true, "");
    $titleArray = get_shop_navigationtitles();
    $contPage = fill_titles($contPage, $SHOP_TITLE, $titleArray[1]);

    // Error occured?
    if ($errorMessage != "")
        $contPage = build_error_message($errorMessage, $contPage);

    // Main content
    $contMain = build_shop_login();
    $contMain .= $cFile->LoadFromFile($BASKETTITLE_CONFIG_FILE);
    if ($basket->IsEmpty() == true)  // Empty basket
    {
        $contMain .= echo_sr ('<br><p><b>' . $cTrans->GetTranslation('shop_basket_empty') . '!</b></p><br>');
        $contMain .= build_shop_bottom_links("bsk_Cancel", $cTrans->GetTranslation('shop_basket_backtoshop'));
    }
    else  // Filled basket
    {
        $contMain .= echo_sr ('<table class="con_tbl" id="bsk_con_tbl">');
        $contMain .= echo_sr ('<tr>');
        $contMain .= echo_sr ('  <td width="11%">' . $cTrans->GetTranslation('shop_basket_image') . '</td>');
        $contMain .= echo_sr ('  <td width="11%">' . $cTrans->GetTranslation('shop_basket_name') . '</td>');
        $contMain .= echo_sr ('  <td width="11%">' . $cTrans->GetTranslation('shop_basket_price') . '</td>');
        $contMain .= echo_sr ('  <td width="11%">' . $cTrans->GetTranslation('shop_basket_count') . '</td>');
        $contMain .= echo_sr ('  <td width="30%">' . $cTrans->GetTranslation('shop_basket_userdefined') . '</td>');
        $contMain .= echo_sr ('  <td width="26%"></td>');
        $contMain .= echo_sr ('</tr>');
        $artIds = $basket->GetArticleIds();
        $artCounts = $basket->GetCounts();
        $artAddToPrices = $basket->GetAddToPrices();
        $artCNames = array();
        $artCFields = array();
        for ($i = 0; $i < count($artIds); $i ++)
        {
            $contMain .= echo_sr ('<tr>');
            $contMain .= echo_sr ('<form method="post" action="">');
            $art->LoadArticleFromId($artIds[$i]);
            $contMain .= echo_sr ('  <td>');
            $contMain .= echo_sr ('  <a href="' . $SHOP_DETAIL_SITE . '?art_id=' . $artIds[$i] . '">');
            $contMain .= echo_sr ('  <img class="basket_img" width="' . $BASKET_IMAGE_WIDTH. '" height="' . $BASKET_IMAGE_HEIGHT . '" src="' . $art->GetImgUrl() . '" title="' . $art->GetName() . '"></a></td>');
            $contMain .= echo_sr ('  <td>' . $art->GetName() . '</td>');
            $contMain .= echo_sr ('  <td>' . format_price($art->GetPrice() +  $artAddToPrices[$i]) . ' ' . $SHOP_CURRENCY . '</td>');
            $contMain .= echo_sr ('  <td><input type="text" size="3" name="art_cnt" maxlength="8" value="' . $artCounts[$i] . '"></td>');
            $basketCount += $artCounts[$i];
            $basketValue += (($art->GetPrice() + $artAddToPrices[$i]) * $artCounts[$i]);
            // Custom fields
            $artCNames = $basket->GetArticleCustNames($i);
            $artCFields = $basket->GetArticleCustFields($i);
            $contMain .= echo_sr ('  <td>');
            for ($v = 0; $v < $ARTICLE_CUSTOM_FIELD_COUNT; $v ++)
            {
                if ($artCNames[$v] != "")
                    $contMain .= echo_sr ($artCNames[$v] . '=' . $artCFields[$v] . ' ');
            }
            $contMain .= echo_sr ('  </td>');
            $contMain .= echo_sr ('  <td><input type="submit" class="side_btn" name="bsk_Save" value="' . $cTrans->GetTranslation('shop_basket_save') . '">');
            $contMain .= echo_sr ('      <input type="submit" class="side_btn" name="bsk_Remove" value="' . $cTrans->GetTranslation('shop_basket_remove') . '">');
            $contMain .= echo_sr ('      <input type="hidden" name="art_index" value="' . $i . '">');
            $contMain .= echo_sr ('      <input type="hidden" name="art_id" value="' . $artIds[$i] . '">');
            $contMain .= echo_sr ('  </td>');
            $contMain .= echo_sr ('</form>');
            $contMain .= echo_sr ('</tr>');
        }
        $contMain .= echo_sr ('</table>');

        $contMain .= echo_sr ('<table class="con_tbl">');
        $contMain .= echo_sr ('<tr>');
        $contMain .= echo_sr ('  <td width="25%">' . $cTrans->GetTranslation('shop_basket_articlecount') . ': </td>');
        $contMain .= echo_sr ('  <td>' . $basketCount . '</td>');
        $contMain .= echo_sr ('</tr><tr>');
        $contMain .= echo_sr ('  <td width="25%">' . $cTrans->GetTranslation('shop_basket_articlevalue') . ': </td>');
        $contMain .= echo_sr ('  <td><b>' . format_price($basketValue) . ' ' . $SHOP_CURRENCY . '</b></td>');
        $contMain .= echo_sr ('</tr></table>');

        $contMain .= build_shop_bottom_links("bsk_Clear", $cTrans->GetTranslation('shop_basket_clear'),
                                             "bsk_CashDesk", $cTrans->GetTranslation('shop_basket_order'));
    }
    
    // Additional content
    $contAdditional = "";

    // Put content together
    $contContent = build_site_content($ALIGN_TOP, $contMain, $contAdditional);
    $contPage = fill_content($contPage, $contContent, "", "");
    $contPage = fill_emptyvars($contPage);

    echo_r($contPage);

?>